@@ -144,17 +144,14 @@ def create_expectations(
 def create_importance(
     func: Callable,
     x: pandas.DataFrame,
-    y: pandas.Series,
     endpoint_name: str,
     profile_columns: List[str],
     kind: str,
 ) -> None:
 
     logging.info("Explanations - Calculating variable importance")
-    if kind == "regression":
-        chart, varlist = varimp(func, x, y, profile_columns, metric="Rmse")
-    elif kind == "binary":
-        chart, varlist = varimp(func, x, y, profile_columns, metric="AUC")
+    if kind in ["regression", "binary"]:
+        chart, varlist = varimp(func, x, profile_columns=profile_columns)
     else:
         raise NotImplementedError("Unknown endpoint kind:" + kind)
 
