@@ -25,7 +25,7 @@ def partialdep(func: Callable[[pd.DataFrame], pd.Series], x: pd.DataFrame, var:
     elif is_numeric_dtype(x[var]):
         return partialdep_num(func=func, x=x, var=var)
     elif is_datetime64_any_dtype(x[var]):
-        return partialdep_num(func=func, x=x, var=var)
+        return partialdep_datetime(func, x=x, var=var)
     else:
         pass
 
@@ -180,3 +180,75 @@ def partialdep_cat(
     )
 
     return lines + mean
+
+
+def partialdep_datetime(
+    func: Callable[[pd.DataFrame], pd.Series], x: pd.DataFrame, var: str
+) -> alt.Chart:
+    """Plot partial dependence for datetime variables"""
+    non_missing = ~x[var].isna()
+    x = x[non_missing]
+
+    # Downsample large dataframes
+    n_obs = len(x)
+    n_max = 100
+    if n_obs > n_max:
+        id_sample = np.random.choice(n_obs, size=n_max, replace=False)
+        x = x.iloc[id_sample]
+
+    # Determine evaluation points (deciles)
+    if x[var].nunique() >= 10:
+        quantiles = np.quantile(
+            x[var], q=np.linspace(0.1, 0.9, 9), interpolation="nearest"
+        )
+    else:
+        quantiles = np.sort(x[var].unique())
+
+    # Calculate centered ICE plots
+    df_ice = pd.DataFrame()
+    for i, quantile in enumerate(quantiles):
+        x_mod = x.copy()
+        x_mod[var] = quantile
+        pred_q = func(x_mod)
+
+        if i == 0:
+            offset = pred_q - np.mean(pred_q)  # for centering
+
+        pred_q_centered = pred_q - offset
+        df_ice_q = pd.DataFrame(
+            {
+                "id": np.arange(len(x_mod)),
+                var: quantile,
+                "Predicted Value": pred_q_centered,
+            }
+        )
+        df_ice = df_ice.append(df_ice_q, ignore_index=True, sort=False)
+
+    df_mean = df_ice.groupby(by=var, as_index=False).agg({"Predicted Value": "mean"})
+
+    # Create plot
+    var_sanitized = vega_sanitize(var, datatype="T")
+
+    lines = (
+        alt.Chart(df_ice)
+        .mark_line(strokeOpacity=0.3, color="grey", strokeWidth=2)
+        .encode(
+            x=var_sanitized,
+            y=alt.Y("Predicted Value:Q", scale=alt.Scale(zero=False)),
+            detail="id",
+        )
+    )
+    mean = (
+        alt.Chart(df_mean)
+        .mark_line(strokeWidth=3, point=True)
+        .encode(
+            x=var_sanitized,
+            y=alt.Y("Predicted Value:Q", scale=alt.Scale(zero=False)),
+            tooltip=[
+                alt.Tooltip(var_sanitized, format=".2f"),
+                alt.Tooltip(f"Predicted Value:Q", format=".2f"),
+            ],
+        )
+        .interactive()
+    )
+    return lines + mean
