@@ -56,14 +56,14 @@ def condexp_num(
     df_act = (
         df.groupby("groups")
         .agg({var: "mean", "y": "mean"})
-        .assign(Type="Actual Value")
+        .assign(__taktile_profiling_value_type__="Actual Value")
         .rename(columns={"y": y.name})
     )
 
     df_pred = (
         df.groupby("groups")
         .agg({var: "mean", "pred": "mean"})
-        .assign(Type="Predicted Value")
+        .assign(__taktile_profiling_value_type__="Predicted Value")
         .rename(columns={"pred": y.name})
     )
 
@@ -77,9 +77,11 @@ def condexp_num(
         .encode(
             x=alt.X(var_sanitized, scale=alt.Scale(zero=False)),
             y=alt.Y(y.name, scale=alt.Scale(zero=False)),
-            color="Type:N",
+            color=alt.Color(
+                "__taktile_profiling_value_type__:N", legend=alt.Legend(title="Type")
+            ),
             tooltip=[
-                "Type:N",
+                alt.Tooltip("__taktile_profiling_value_type__:N", title="Type"),
                 alt.Tooltip(var_sanitized, format=".2f"),
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
@@ -128,9 +130,11 @@ def condexp_cat(
     ordered_categories = list(df_agg[var].cat.categories)
 
     df_pred = df_agg.rename(columns={"Predicted Value": y.name}).assign(
-        Type="Predicted Value"
+        __taktile_profiling_value_type__="Predicted Value"
+    )
+    df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(
+        __taktile_profiling_value_type__="Actual Value"
     )
-    df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(Type="Actual Value")
 
     # Create plot
     var_sanitized = vega_sanitize(var, datatype="N")
@@ -143,9 +147,11 @@ def condexp_cat(
             y=alt.Y(
                 var_sanitized, sort=ordered_categories, scale=alt.Scale(zero=False),
             ),
-            color="Type:N",
+            color=alt.Color(
+                "__taktile_profiling_value_type__:N", legend=alt.Legend(title="Type")
+            ),
             tooltip=[
-                "Type:N",
+                alt.Tooltip("__taktile_profiling_value_type__:N", title="Type"),
                 var_sanitized,
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
@@ -159,9 +165,11 @@ def condexp_cat(
         .encode(
             x=alt.X(y.name, scale=alt.Scale(zero=False)),
             y=alt.Y(var_sanitized, sort=ordered_categories),
-            color="Type:N",
+            color=alt.Color(
+                "__taktile_profiling_value_type__:N", legend=alt.Legend(title="Type")
+            ),
             tooltip=[
-                "Type:N",
+                alt.Tooltip("__taktile_profiling_value_type__:N", title="Type"),
                 var_sanitized,
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
@@ -199,9 +207,11 @@ def condexp_datetime(func, X, y, var, n_max=100):
     )
 
     df_pred = df_agg.rename(columns={"Predicted Value": y.name}).assign(
-        Type="Predicted Value"
+        __taktile_profiling_value_type__="Predicted Value"
+    )
+    df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(
+        __taktile_profiling_value_type__="Actual Value"
     )
-    df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(Type="Actual Value")
 
     df = df_pred.append(df_act, ignore_index=True)
 
@@ -214,9 +224,11 @@ def condexp_datetime(func, X, y, var, n_max=100):
         .encode(
             x=var_sanitized,
             y=alt.Y(y.name, scale=alt.Scale(zero=False)),
-            color="Type:N",
+            color=alt.Color(
+                "__taktile_profiling_value_type__:N", legend=alt.Legend(title="Type")
+            ),
             tooltip=[
-                "Type:N",
+                alt.Tooltip("__taktile_profiling_value_type__:N", title="Type"),
                 alt.Tooltip(var_sanitized, format=".2f"),
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
